# A description of what this class does
#
# @summary A short summary of the purpose of this class
#
# @example
#   include workstation::user
class workstation::user (
  String[1] $user = $workstation::user,
  String[1] $home = $workstation::home,
  Enum['bash', 'zsh', 'fish'] $shell = $workstation::shell,
  String[1] $fish_mac_pkg_url = 'https://github.com/fish-shell/fish-shell/releases/download/3.0.0/fish-3.0.0.pkg',
) {

  # if $shell == 'fish' {
  #   if $facts['os']['family'] == 'Darwin' {
  #     package { 'fish':
  #       ensure => installed,
  #       source => $fish_pkg_url,
  #       before => User[$user],
  #     }
  #   } else {
  #     package { 'fish':
  #       ensure => present,
  #       name   => 'fish',
  #       before => User[$user],
  #     }
  #   }
  # }

  case $shell {
    'bash': {
      $bash_config = $facts['os']['family'] ? {
        'Darwin' => "${home}/.bash_profile",
        default  => "${home}/.bashrc",
      }

      file { $bash_config:
        ensure => file,
        owner  => $user,
      }
    }
    'fish': {
      case $facts['os']['family'] {
        'Darwin': {
          package { 'fish':
            ensure => present,
            source => $fish_mac_pkg_url,
          }
        }
        default: {
          package { 'fish':
            ensure => present,
          }
        }
      }

      $fish_dirs = [
        "${home}/.config/",
        "${home}/.config/fish/",
        "${home}/.config/fish/completions",
        "/usr/local/share/fish",
      ]

      file { $fish_dirs:
        ensure => directory,
        owner  => $user,
      }

      file { "${home}/.config/fish/config.fish":
        ensure => file,
        owner  => $user,
      }
    }
    default: { fail("Unsupported shell: ${shell}") }
  }

  $shell_path = $shell ? {
    'bash' => '/bin/bash',
    'zsh'  => '/bin/zsh',
    'fish' => '/usr/local/bin/fish',
  }

  case $facts['os']['family'] {
    'Darwin': {
      $require_pkg = $shell ? {
        'fish'  => 'fish',
        default => undef,
      }
    }
    default: {
      $require_pkg = $shell ? {
        'fish'  => 'fish',
        'zsh'   => 'zsh',
        default => undef,
      }
    }
  }

  user { $user:
    shell   => $shell_path,
    home    => $home,
    require => Package[$require_pkg],
  }

}
